@@ -10,7 +10,7 @@ use Scalar::Util();
 use Rose::HTML::Util();
 use Rose::HTML::Object::Message::Localizer;
 
-our $VERSION = '0.554';
+our $VERSION = '0.600';
 
 our $Debug = undef;
 
@@ -27,6 +27,7 @@ use Rose::Class::MakeMethods::Generic
 );
 
 __PACKAGE__->default_localizer(Rose::HTML::Object::Message::Localizer->new);
+__PACKAGE__->default_locale('en');
 
 __PACKAGE__->autoload_html_attr_methods(1);
 
@@ -63,8 +64,6 @@ __PACKAGE__->object_type_classes
   'form'               => 'Rose::HTML::Form',
   'repeatable form'    => 'Rose::HTML::Form::Repeatable',
 
-  #'repeatable field'   => 'Rose::HTML::Form::Field::Repeatable',
-
   'text'               => 'Rose::HTML::Form::Field::Text',
   'scalar'             => 'Rose::HTML::Form::Field::Text',
   'char'               => 'Rose::HTML::Form::Field::Text',
@@ -229,6 +228,14 @@ use Rose::HTML::Object::MakeMethods::Generic
   ],
 );
 
+#
+# Class methods
+#
+
+sub generic_object_class { __PACKAGE__ }
+
+*object_type_names = \&object_type_class_keys;
+
 #
 # Constructor
 #
@@ -242,7 +249,7 @@ sub new
     html_attrs  => {},
     escape_html => 1,
     error       => undef,
-    validate_html_attrs => $class eq __PACKAGE__ ? 0 : 1,
+    validate_html_attrs => $class eq $class->generic_object_class ? 0 : 1,
   };
 
   bless $self, $class;
@@ -374,10 +381,22 @@ sub object_type_class_loaded
 
     $Loaded{$type_class}++;
   }
-  
+
   return $type_class;
 }
 
+sub message_for_error_id
+{
+  my($self, %args) = @_;
+
+  my $error_id  = $args{'error_id'};
+  my $msg_class = $args{'msg_class'} || $self->localizer->message_class;
+  my $args      = $args{'args'} || [];
+
+  return $msg_class->new(id => $error_id, args => $args);
+}
+
+
 sub init_html_error_formatter  { }
 sub init_xhtml_error_formatter { }
 
@@ -792,6 +811,15 @@ sub default_html_attr_value
   return $class->required_html_attr_value($attr);
 }
 
+sub load_all_messages
+{
+  my($self_or_class) = shift;
+
+  my $class = ref($self_or_class) || $self_or_class;
+
+  $class->localizer->load_all_messages(from_class => $class);
+}
+
 our $AUTOLOAD;
 
 # We "can" do what will eventually be AUTOLOADed HTML attribute methods
@@ -847,7 +875,7 @@ sub create_html_attr_methods
 sub import
 {
   my($class) = shift;
-  
+
   foreach my $arg (@_)
   {
     if($arg eq ':customize')
@@ -857,11 +885,15 @@ sub import
         qw(object_type_class_exists object_type_class_keys 
            delete_object_type_class object_type_classes 
            clear_object_type_classes object_type_class 
-           inherit_object_type_classs object_type_classes_cache 
-           inherit_object_type_class add_object_type_classs 
+           inherit_object_type_classes object_type_classes_cache 
+           inherit_object_type_class add_object_type_classes 
            delete_object_type_classes add_object_type_class
            localizer locale default_localizer default_locale));
     }
+    else
+    {
+      carp "$class: Unknown import argument '$arg'";
+    }
   }
 }
 
@@ -1011,11 +1043,11 @@ Rose::HTML::Object - HTML object base class.
   print $br->html;  # <br>
   print $br->xhtml; # <br />
 
-  $o->unshift_children($br, ' ');
+  $o->unshift_children($br, ' '); # add two children
 
   print $o->html; # <p><br> Hi</p>
 
-  $b = Rose::HTML::Object->new(body => children => $o);
+  $b = Rose::HTML::Object->new('body', children => $o);
 
   print $b->html; # <body><p><br> Hi</p></body>
 
@@ -1026,15 +1058,11 @@ Rose::HTML::Object - HTML object base class.
 
   $d = Rose::HTML::Object->new('div', class => 'x');
 
-  $b->child(0)->parent($d); # re-parent
+  $b->child(0)->parent($d); # re-parent: $o now belongs to $d
 
   print $b->html; # <body></body>
   print $d->html; # <div class="x"><p><br> Hi</p></div>
 
-
-
-
-
   #
   # Subclass to add strictures
   #
@@ -1065,6 +1093,7 @@ Rose::HTML::Object - HTML object base class.
 
   sub html_element  { 'mytag' }
   sub xhtml_element { 'mytag' }
+
   ...
 
   my $o = MyTag->new(bar => 'hello', selected => 1);
@@ -1073,15 +1102,17 @@ Rose::HTML::Object - HTML object base class.
   print $o->html_attrs_string;  
 
   # prints: bar="hello" foo="5" goo="" selected="selected"
-  print $o->xhtml_attrs_string; 
+  print $o->xhtml_attrs_string;
 
   $o->html_attr(selected => 0);
 
-  print "Has bar"  if($o->html_attr_exists('bar'));
+  print "Has bar\n"  if($o->html_attr_exists('bar'));
   $o->delete_html_attr('bar');
 
-  print $o->html_tag;  # <mytag foo="5" goo="" selected>
-  print $o->xhtml_tag; # <mytag foo="5" goo="" selected="selected" />
+  $o->is_self_closing(1);
+
+  print $o->html_tag;  # <mytag foo="5" goo="">
+  print $o->xhtml_tag; # <mytag foo="5" goo="" />
   ...
 
 =head1 DESCRIPTION
@@ -1098,15 +1129,15 @@ Each L<Rose::HTML::Object> may have zero or more L<children|/children>, each of
 
 Although several methods, data structures, and policies exist to aid the creation of valid HTML, they are in no way a replacement for real markup validation.
 
-This class and those that inherit from it try to support a superset of the elements and attributes specified in the HTML 4.01 and XHTML 1.x specifications.  As a result, these classes will tend to be more permissive than actual validation.  The support of these standards is not exhaustive, and will inevitably expand.  Also remember that there are several variant DTDs that make up XHTML 1.x.  By trying to support a superset of these standards, this class simply can't correctly enforce the rules of any individual standard.
+This class and those that inherit from it try to support a superset of the elements and attributes specified in the HTML 4.01 and XHTML 1.x specifications.  As a result, these classes will tend to be more permissive than actual validation.  The support of these standards is not exhaustive, and will inevitably expand.  Also remember that there are several variant DTDs that make up XHTML 1.x.  By trying to support a superset of these standards, this class can't correctly enforce the rules of any individual standard.
 
-So I say again: these classes are not a replacement for real markup validation! Use an external validator!
+So I say again: these classes are not a replacement for real markup validation. Use an external validator.
 
 Going forward, the compatibility policy of these classes is that attribute specifications may be added in the future, but existing attribute specifications will never be removed (unless they originally existed in error, i.e., were never part of any HTML 4.01 or XHTML 1.x standard).
 
 This support policy is pragmatic rather than ideological.  There is enough default validation to catch most typos or other unintentional errors, but not so much that the entire class hierarchy is weighed down by language lawyering and bookkeeping.
 
-If the runtime overhead of validating every HTML attribute is deemed too onerous, it can be turned off on a per-object basis with the L<validate_html_attrs()|/validate_html_attrs> method.   Subclasses can set this attribute during object construction to make the effect class-wide.  (You will also want to look at the L<autoload_html_attr_methods()|/autoload_html_attr_methods> class attribute.)
+If the runtime overhead of validating every HTML attribute is deemed too onerous, it can be turned off on a per-object basis with the L<validate_html_attrs|/validate_html_attrs> method.   Subclasses can set this attribute during object construction to make the effect class-wide.  (You will also want to look at the L<autoload_html_attr_methods|/autoload_html_attr_methods> class attribute.)
 
 There are also methods for adding and removing valid, required, and boolean HTML attributes for a class.
 
@@ -1116,9 +1147,9 @@ Finally, all element and attribute names are case-sensitive and lowercase in ord
 
 These class methods can be called with a class name or an object as the invocant.  Either way, remember that the data structures and attributes affected are part of the class as a whole, not any individual object.  For example, adding a valid HTML attribute makes it valid for all objects of the class, including any objects that already exist.
 
-Many of the class methods manipulate "inheritable sets" or "inherited sets." See the L<Rose::Class::MakeMethods::Set> documentation for an explanation off these method types.
+Many of the class methods manipulate "inheritable sets," "inherited sets," or "inherited hashes."  See the L<Rose::Class::MakeMethods::Set> and L<Rose::Class::MakeMethods::Generic|Rose::Class::MakeMethods::Generic/inherited_hash> documentation for an explanation of these method types.
 
-The sets of valid and boolean HTML attributes are "inherited sets."  The set of required HTML attributes is an "inheritable set."
+The sets of valid and boolean HTML attributes are "inherited sets."  The set of required HTML attributes is an "inheritable set."  The L<object_type_classes|/object_type_classes> map is an "inherited hash."
 
 The inheritance behavior of these sets is noted here in order to facilitate subclassing.  But it is an implementation detail, not a part of the public API.  The requirements of the APIs themselves do not include any particular inheritance behavior.
 
@@ -1132,13 +1163,24 @@ Adds a value to the list of boolean HTML attributes for this class. Boolean HTML
 
 Adds one or more values to the list of boolean HTML attributes for this class. Boolean HTML attributes appear without values in HTML tags, (e.g., <dl compact>) or with fixed values in XHTML tags (e.g., <dl compact="compact">)
 
+=item B<add_object_type_classes [MAP]>
+
+Add entries to the L<object_type_classes|/object_type_classes> hash that maps object type strings to the names of the L<Rose::HTML::Object>-derived classes.  Example:
+
+    My::HTML::Form->add_object_type_classes
+    (
+      blockquote => 'My::HTML::Blockquote',
+      abbr       => 'My::HTML::Abbr',
+      ...
+    );
+
 =item B<add_required_html_attr NAME [, DEFAULT]>
 
-Adds a value to the list of required HTML attributes for this class. Required HTML attributes will always appear in the HTML tag, with or without a non-empty value. You can set the default value for a required HTML attribute using the L<required_html_attr_value()|/required_html_attr_value> method or by passing the DEFAULT parameter to this method.
+Adds a value to the list of required HTML attributes for this class. Required HTML attributes will always appear in the HTML tag, with or without a non-empty value. You can set the default value for a required HTML attribute using the L<required_html_attr_value|/required_html_attr_value> method or by passing the DEFAULT parameter to this method.
 
 =item B<add_required_html_attrs NAME1, NAME2, ... | HASHREF>
 
-Adds one or more values to the list of required HTML attributes for this class. Required HTML attributes will always appear in the HTML tag, with or without a non-empty value.  You can set the default value for a required HTML attribute using the L<required_html_attr_value()|/required_html_attr_value> method or by passing a reference to a hash containing name/default pairs.
+Adds one or more values to the list of required HTML attributes for this class. Required HTML attributes will always appear in the HTML tag, with or without a non-empty value.  You can set the default value for a required HTML attribute using the L<required_html_attr_value|/required_html_attr_value> method or by passing a reference to a hash containing name/default pairs.
 
 =item B<add_valid_html_attr NAME>
 
@@ -1156,7 +1198,7 @@ In the case of a name conflict, the existing method is called and a new method i
 
 Examples:
 
-    MyTag->add_valid_httml_attrs('foo', 'bar', 'error');
+    MyTag->add_valid_html_attrs('foo', 'bar', 'error');
 
     $o = MyTag->new;
 
@@ -1180,7 +1222,7 @@ Examples:
 
 Yes, the existence of this capability means that adding a method to a future version of a L<Rose::HTML::Object>-derived class that has the same name as a valid HTML attribute may cause older code that calls the auto-created method of the same name to break.
 
-You have a few options.  You can simply choose not to use any auto-created methods, opting instead to use L<html_attr()|/html_attr> everywhere (and you can set C<autoload_html_attr_methods> to false to make sure that you don't accidentally use such a method).  Or you can simply trust that I will not add new methods with the same names as existing valid HTML attributes.  Since I use auto-created methods extensively, you can have some faith that I will do everything I can to avoid breaking my own code.
+To avoid this, you can choose not to use any auto-created methods, opting instead to use the L<html_attr|/html_attr> method everywhere (and you can set C<autoload_html_attr_methods> to false to make sure that you don't accidentally use such a method).
 
 =item B<boolean_html_attrs>
 
@@ -1194,10 +1236,22 @@ Returns the default value for the HTML attribute NAME.
 
 If passed both an attribute NAME and a VALUE, it adds NAME to the set of required HTML attributes and sets its default value to VALUE.
 
+=item B<default_locale [LOCALE]>
+
+Get or set the default L<locale|Rose::HTML::Object::Message::Localizer/LOCALES> for this class.  The default value C<en>.
+
+=item B<default_localizer [LOCALIZER]>
+
+Get or set the default L<Rose::HTML::Object::Message::Localizer>-derived localizer object.  Defaults to a new L<Rose::HTML::Object::Message::Localizer>-derived object.
+
 =item B<delete_boolean_html_attr NAME>
 
 Removes the HTML attribute NAME from the set of boolean HTML attributes.
 
+=item B<delete_object_type_class TYPE>
+
+Delete the type/class L<mapping|/object_type_classes> entry for the object type TYPE.
+
 =item B<delete_required_html_attr NAME>
 
 Removes the HTML attribute NAME from the set of required HTML attributes.
@@ -1218,11 +1272,141 @@ Returns a boolean value indicating whether or not the attribute NAME is a requir
 
 Returns a boolean value indicating whether or not the attribute NAME is a valid HTML attribute.
 
+=item B<load_all_messages>
+
+Ask the L<localizer|/localizer> to L<load_all_messages|Rose::HTML::Object::Message::Localizer/load_all_messages> from this class.
+
+=item B<locale [LOCALE]>
+
+This method may be called as a class method or an object method.
+
+When called as a class method and a L<LOCALE|Rose::HTML::Object::Message::Localizer/LOCALES> is passed, then the L<default_locale|/default_locale> is set.  When called as an object method and a L<LOCALE|Rose::HTML::Object::Message::Localizer/LOCALES> is passed, then the L<locale|Rose::HTML::Object::Message::Localizer/LOCALES> of this object is set.
+
+If no locale is set for this class (when called as a class method) then the L<localizer|/localizer>'s L<locale|Rose::HTML::Object::Message::Localizer/locale> is returned, if it is set.  Otherwise, the L<default_locale|/default_locale> is returned.
+
+If no locale is set for this object (when called as an object method), then the the first defined locale from the object's L<parent_group|Rose::HTML::Form::Field/parent_group>, L<parent_field|Rose::HTML::Form::Field/parent_field>, L<parent_form|Rose::HTML::Form::Field/parent_form>, or generic L<parent|/parent> is returned.  If none of those locales are defined, then the L<localizer|/localizer>'s L<locale|Rose::HTML::Object::Message::Localizer/locale> is returned, if it is set.  Otherwise, the L<default_locale|/default_locale> is returned.
+
+=item B<object_type_class TYPE [, CLASS]>
+
+Given the object type string TYPE, return the name of the L<Rose::HTML::Object>-derived class mapped to that name.  If a CLASS is passed, the object type TYPE is mapped to CLASS.
+
+This map of type names to classes is an L<inherited hash|Rose::Class::MakeMethods::Generic/inherited_hash> representing the union of the hashes of all superclasses, minus any keys that are explicitly L<deleted|/delete_object_type_class> in the current class.
+
+=item B<object_type_classes [MAP]>
+
+Get or set the hash that maps object type strings to the names of the L<Rose::HTML::Object>-derived classes.
+
+If passed MAP (a list of type/class pairs or a reference to a hash of the same) then MAP replaces the current object type mapping.  Returns a list of type/class pairs (in list context) or a reference to a hash of type/class mappings (in scalar context).
+
+This map of type names to classes is an L<inherited hash|Rose::Class::MakeMethods::Generic/inherited_hash> representing the union of the hashes of all superclasses, minus any keys that are explicitly L<deleted|/delete_object_type_class> in the current class.
+
+The default mapping of type names to class names is:
+
+  'image'              => Rose::HTML::Image
+  'label'              => Rose::HTML::Label
+  'link'               => Rose::HTML::Link
+  'script'             => Rose::HTML::Script
+  'literal text'       => Rose::HTML::Text
+
+  'form'               => Rose::HTML::Form
+  'repeatable form'    => Rose::HTML::Form::Repeatable
+
+  'text'               => Rose::HTML::Form::Field::Text
+  'scalar'             => Rose::HTML::Form::Field::Text
+  'char'               => Rose::HTML::Form::Field::Text
+  'character'          => Rose::HTML::Form::Field::Text
+  'varchar'            => Rose::HTML::Form::Field::Text
+  'string'             => Rose::HTML::Form::Field::Text
+
+  'text area'          => Rose::HTML::Form::Field::TextArea
+  'textarea'           => Rose::HTML::Form::Field::TextArea
+  'blob'               => Rose::HTML::Form::Field::TextArea
+
+  'option'             => Rose::HTML::Form::Field::Option
+  'option group'       => Rose::HTML::Form::Field::OptionGroup
+
+  'checkbox'           => Rose::HTML::Form::Field::Checkbox
+  'check'              => Rose::HTML::Form::Field::Checkbox
+
+  'radio button'       => Rose::HTML::Form::Field::RadioButton
+  'radio'              => Rose::HTML::Form::Field::RadioButton
+
+  'checkboxes'         => Rose::HTML::Form::Field::CheckboxGroup
+  'checks'             => Rose::HTML::Form::Field::CheckboxGroup
+  'checkbox group'     => Rose::HTML::Form::Field::CheckboxGroup
+  'check group'        => Rose::HTML::Form::Field::CheckboxGroup
+
+  'radio buttons'      => Rose::HTML::Form::Field::RadioButtonGroup
+  'radios'             => Rose::HTML::Form::Field::RadioButtonGroup
+  'radio button group' => Rose::HTML::Form::Field::RadioButtonGroup
+  'radio group'        => Rose::HTML::Form::Field::RadioButtonGroup
+
+  'pop-up menu'        => Rose::HTML::Form::Field::PopUpMenu
+  'popup menu'         => Rose::HTML::Form::Field::PopUpMenu
+  'menu'               => Rose::HTML::Form::Field::PopUpMenu
+
+  'select box'         => Rose::HTML::Form::Field::SelectBox
+  'selectbox'          => Rose::HTML::Form::Field::SelectBox
+  'select'             => Rose::HTML::Form::Field::SelectBox
+
+  'submit'             => Rose::HTML::Form::Field::Submit
+  'submit button'      => Rose::HTML::Form::Field::Submit
+
+  'reset'              => Rose::HTML::Form::Field::Reset
+  'reset button'       => Rose::HTML::Form::Field::Reset
+
+  'file'               => Rose::HTML::Form::Field::File
+  'upload'             => Rose::HTML::Form::Field::File
+
+  'password'           => Rose::HTML::Form::Field::Password
+
+  'hidden'             => Rose::HTML::Form::Field::Hidden
+
+  'num'                => Rose::HTML::Form::Field::Numeric
+  'number'             => Rose::HTML::Form::Field::Numeric
+  'numeric'            => Rose::HTML::Form::Field::Numeric
+
+  'int'                => Rose::HTML::Form::Field::Integer
+  'integer'            => Rose::HTML::Form::Field::Integer
+
+  'email'              => Rose::HTML::Form::Field::Email
+
+  'phone'              => Rose::HTML::Form::Field::PhoneNumber::US
+  'phone us'           => Rose::HTML::Form::Field::PhoneNumber::US
+
+  'phone us split' =>
+    Rose::HTML::Form::Field::PhoneNumber::US::Split
+
+  'set'  => Rose::HTML::Form::Field::Set
+
+  'time' => Rose::HTML::Form::Field::Time
+
+  'time split hms' => 
+    Rose::HTML::Form::Field::Time::Split::HourMinuteSecond
+
+  'time hours'       => Rose::HTML::Form::Field::Time::Hours
+  'time minutes'     => Rose::HTML::Form::Field::Time::Minutes
+  'time seconds'     => Rose::HTML::Form::Field::Time::Seconds
+
+  'date'             => Rose::HTML::Form::Field::Date
+  'datetime'         => Rose::HTML::Form::Field::DateTime
+
+  'datetime range'   => Rose::HTML::Form::Field::DateTime::Range
+
+  'datetime start'   => Rose::HTML::Form::Field::DateTime::StartDate
+  'datetime end'     => Rose::HTML::Form::Field::DateTime::EndDate
+
+  'datetime split mdy' => 
+    Rose::HTML::Form::Field::DateTime::Split::MonthDayYear
+
+  'datetime split mdyhms' => 
+    Rose::HTML::Form::Field::DateTime::Split::MDYHMS
+
 =item B<required_html_attrs>
 
 Returns a reference to a sorted list of required HTML attributes in scalar context, or a sorted list of required HTML attributes in list context. The default set of required HTML attributes is empty.
 
-Required HTML attributes are included in the strings generated by L<html_attrs_string()|/html_attrs_string> and L<xhtml_attrs_string()|/xhtml_attrs_string> even if they have been deleted by L<delete_html_attr()|/delete_html_attr> or one of its variants.  If a required HTML attribute does not have a default value, its value defaults to an empty string or, if the attribute is also boolean, the name of the attribute.
+Required HTML attributes are included in the strings generated by the L<html_attrs_string|/html_attrs_string> and L<xhtml_attrs_string|/xhtml_attrs_string> methods, even if they have been deleted using the L<delete_html_attr|/delete_html_attr> method or one of its variants.  If a required HTML attribute does not have a default value, its value defaults to an empty string or, if the attribute is also boolean, the name of the attribute.
 
 See the introduction to the L<"CLASS METHODS"> section for more information about the "inheritable set" implementation used by the set of boolean HTML attributes.
 
@@ -1284,7 +1468,7 @@ This is an alias for the L<push_child|/push_child> method.
 
 This is an alias for the L<push_children|/push_children> method.
 
-=item B<child [INT]>
+=item B<child INT>
 
 Returns the L<child|/children> at the index specified by INT.  The first child is at index zero (0).
 
@@ -1312,7 +1496,7 @@ Deletes all the HTML attributes.
 
 =item B<delete_child [ INDEX | OBJECT ]>
 
-Delete the L<child|/children> at INDEX (starting from zero) or the exact child OBJECT.
+Delete the L<child|/child> at INDEX (starting from zero) or the exact child OBJECT.
 
 =item B<delete_children>
 
@@ -1338,21 +1522,28 @@ If passed a NAME, sets both L<html_element|/html_element> and L<xhtml_element|/x
 
 Get or set an error string.
 
+=item B<error_id [ID [, ARGS]]>
+
+Get or set an integer L<error|Rose::HTML::Object::Errors> id.  When setting the error id, an optional ARGS hash reference should be passed if the L<localized text|Rose::HTML::Object::Message::Localizer/"LOCALIZED TEXT"> for the L<corresponding|/message_for_error_id> message contains any L<placeholders|Rose::HTML::Object::Message::Localizer/"LOCALIZED TEXT">.  Example:
+
+  # Set error id, passing args for the label and value placeholders
+  $obj->error_id(NUM_ABOVE_MAX, { label => $l, => value => $v });
+
 =item B<escape_html [BOOL]>
 
 This flag may be used by other methods to decide whether or not to escape HTML.  It is set to true by default.  The only method in L<Rose::HTML::Object> that references it is L<html_error|/html_error>.  All other HTML is escaped as appropriate regardless of the L<escape_html|/escape_html> setting (e.g. the text returned by C<html_attrs_string> always has its attribute values escaped).  Subclasses may consult this flag for similar purposes (which they must document, of course).
 
 =item B<has_child OBJECT>
 
-Returns true if OBJECT is a L<child|/children> of this object, false otherwise.
+Returns true if OBJECT is a L<child|/child> of this object, false otherwise.
 
 =item B<has_children>
 
-Returns true if there are any L<children|/children>, false otherwise.
+Returns true if there are any L<children|/child>, false otherwise.
 
 =item B<has_parent>
 
-Returns true if this object is the L<child|/children> of another object, false otherwise.
+Returns true if this object is the L<child|/child> of another object, false otherwise.
 
 =item B<has_error>
 
@@ -1360,7 +1551,7 @@ Returns true if an L<error|/error> is set, false otherwise.
 
 =item B<html>
 
-A synonym for L<html_tag()|/html_tag>.
+A synonym for the L<html_tag|/html_tag> method.
 
 =item B<html_attr NAME [, VALUE]>
 
@@ -1458,11 +1649,11 @@ If the L<escape_html|/escape_html> flag is set to true (the default), then the e
 
 =item B<html_tag>
 
-Serializes the object as an HTML tag.  In other words, it is the concatenation of the strings returned by L<html_element()|/html_element> and L<html_attrs_string()|/html_attrs_string>, wrapped with the appropriate angled brackets.
+Serializes the object as an HTML tag.  In other words, it is the concatenation of the strings returned by the L<html_element|/html_element> and L<html_attrs_string|/html_attrs_string> methods, wrapped with the appropriate angled brackets.
 
 =item B<is_self_closing [BOOL]>
 
-Get or set a boolean attribute that determines whether or not the HTML for this object requires a separate closing tag.  If set to true, then an empty "foo" tag would looke like this:
+Get or set a boolean attribute that determines whether or not the HTML for this object requires a separate closing tag.  If set to true, then an empty "foo" tag would look like this:
 
      HTML: <foo>
     XHTML: <foo />
@@ -1474,6 +1665,36 @@ If false, then the tags above would look like this instead:
 
 The default value is false.  This attribute may be read-only in subclasses.
 
+=item B<locale [LOCALE]>
+
+This method may be called as a class method or an object method.
+
+When called as an object method and a L<LOCALE|Rose::HTML::Object::Message::Localizer/LOCALES> is passed, then the L<locale|Rose::HTML::Object::Message::Localizer/LOCALES> of this object is set.  When called as a class method and a L<LOCALE|Rose::HTML::Object::Message::Localizer/LOCALES> is passed, then the L<default_locale|/default_locale> is set.
+
+If no locale is set for this object (when called as an object method), then the the first defined locale from the object's L<parent_group|Rose::HTML::Form::Field/parent_group>, L<parent_field|Rose::HTML::Form::Field/parent_field>, L<parent_form|Rose::HTML::Form::Field/parent_form>, or generic L<parent|/parent> is returned.  If none of those locales are defined, then the L<localizer|/localizer>'s L<locale|Rose::HTML::Object::Message::Localizer/locale> is returned, if it is set.  Otherwise, the L<default_locale|/default_locale> is returned.
+
+If no locale is set for this class (when called as a class method) then the L<localizer|/localizer>'s L<locale|Rose::HTML::Object::Message::Localizer/locale> is returned, if it is set.  Otherwise, the L<default_locale|/default_locale> is returned.
+
+=item B<localizer [LOCALIZER]>
+
+Get or set the L<Rose::HTML::Object::Message::Localizer>-derived object used to localize message text on behalf of this object.  If no localizer is set then the L<default_localizer|/default_localizer> is returned.
+
+=item B<message_for_error_id [PARAMS]>
+
+Given an L<error|Rose::HTML::Object::Errors> id, return the corresponding L<message|Rose::HTML::Object::Message::Localizer/message_class> object.  The default implementation simply looks for a message with the same integer id as the error.  Valid PARAMS name/value pairs are:
+
+=over 4
+
+=item B<error_id ID>
+
+The integer error id.  This parameter is required.
+
+=item B<args HASHREF>
+
+A reference to a hash of name/value pairs to be used as the L<message arguments|Rose::HTML::Object::Message/args>.
+
+=back
+
 =item B<parent [OBJECT]>
 
 Get or set the parent object.
@@ -1490,13 +1711,13 @@ Remove INT objects from the end of the list of L<children|/children> and return
 
 Add OBJECT to the end of the list of L<children|/children>.  The object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  If it's a plain scalar, it will be converted to a L<Rose::HTML::Text> object, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
 
-=item B<push_children OBJECTS>
+=item B<push_children OBJECT1 [, OBJECT2, ...]>
 
-Add OBJECTS to the end of the list of L<children|/children>.  Each object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  All plain scalars will be converted to L<Rose::HTML::Text> objects, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
+Add objects on to the end of the list of L<children|/children>.  Each object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  All plain scalars will be converted to L<Rose::HTML::Text> objects, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
 
 =item B<set_error>
 
-Set the L<error|/error> to a defined but "invisible" (zero-length) value.  This value will not be displayed by the L<html_error|/html_error> or L<xhtml_error|/xhtml_error>.  Use this method when you want to flag a field as having an error, but don't want a visible error message.
+Set the L<error|/error> to a defined but "invisible" (zero-length) value.  This value will not be displayed by the L<html_error|/html_error> or L<xhtml_error|/xhtml_error> methods.  Use this method when you want to flag a field as having an error, but don't want a visible error message.
 
 =item B<shift_child [INT]>
 
@@ -1510,9 +1731,9 @@ Remove INT objects from the start of the list of L<children|/children> and retur
 
 Add OBJECT to the start of the list of L<children|/children>.  The object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  If it's a plain scalar, it will be converted to a L<Rose::HTML::Text> object, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
 
-=item B<unshift_children OBJECTS>
+=item B<unshift_children OBJECT1 [, OBJECT2, ...]>
 
-Add OBJECTS to the start of the list of L<children|/children>.  Each object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  All plain scalars will be converted to L<Rose::HTML::Text> objects, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
+Add objects to the start of the list of L<children|/children>.  Each object must be of or derived from the L<Rose::HTML::Object> class, or a plain scalar.  All plain scalars will be converted to L<Rose::HTML::Text> objects, with the scalar used as the value of the L<text|Rose::HTML::Text/text> attribute.
 
 =item B<unset_error>
 
@@ -1524,7 +1745,7 @@ If set to true, HTML attribute arguments to C<html_attr> and C<html_attr_hook> w
 
 =item B<xhtml>
 
-A synonym for L<xhtml_tag()|/xhtml_tag>.
+A synonym for the L<xhtml_tag|/xhtml_tag> method.
 
 =item B<xhtml_element [NAME]>
 
@@ -1542,7 +1763,7 @@ If the L<escape_html|/escape_html> flag is set to true (the default), then the e
 
 =item B<xhtml_tag>
 
-Serializes the object as an XHTML tag.  In other words, it is the concatenation of the strings returned by L<xhtml_element()|/xhtml_element> and L<xhtml_attrs_string()|/xhtml_attrs_string>, wrapped with the appropriate angled brackets and forward slash character.
+Serializes the object as an XHTML tag.  In other words, it is the concatenation of the strings returned by the L<xhtml_element|/xhtml_element> and L<xhtml_attrs_string|/xhtml_attrs_string> methods, wrapped with the appropriate angled brackets and forward slash character.
 
 =item B<xhtml_attrs_string>
 
@@ -1560,13 +1781,13 @@ Examples:
     $o->html_attrs(color => 'red<', age => 5, happy => 12345);
 
     # ' age="5" color="red&lt;" happy="happy"'
-    $s = $o->html_attrs_string;
+    $s = $o->xhtml_attrs_string;
 
 =back
 
 =head1 SUPPORT
 
-Any L<Rose::HTML::Objects> questions or problems can be posted to the L<Rose::HTML::Objects> mailing list.  To subscribe to the list or view the archives, go here:
+Any L<Rose::HTML::Objects> questions or problems can be posted to the L<Rose::HTML::Objects> mailing list.  To subscribe to the list or search the archives, go here:
 
 L<http://groups.google.com/group/rose-html-objects>
 
@@ -1582,6 +1803,6 @@ L<http://rose.googlecode.com>
 
 John C. Siracusa (siracusa@gmail.com)
 
-=head1 COPYRIGHT
+=head1 LICENSE
 
 Copyright (c) 2008 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
